This function computes the rescaled Epanechnikov kernel for a given value s and bandwidth g:
$$K\left(\frac{s}{g}\right) = \frac{3}{4g} \left( 1 - \left(\frac{s}{g}\right)^2 \right) I\left(\left|\frac{s}{g}\right| \leq 1\right),$$
where \(I\) is the indicator function (it takes the value 1 if the condition is true and 0 otherwise).
Usage
k.epa(g, s)
Value
Rescaled Epanechnikov kernel for the given value s and bandwidth g.
Arguments
g
A numeric value or vector which contains the bandwidth(s).
s
A numeric value or vector with the values of the variable in which the kernel will be evaluated.