This function computes the logarithm of the likelihood of a single-index mixture cure model.
loglik.simcm(x, time, delta, logh1, logh2, logh3, logh4, r, k = 10)A list with two components:
The value of the negative log-likelihood.
The \(n\) terms that contribute to the negative log-likelihood.
A numeric vector giving the covariate values.
A numeric vector giving the observed times.
A numeric vector giving the values of the uncensoring indicator, where 1 indicates that the event of interest has been observed and 0 indicates that the observation is censored.
The logarithm of the bandwidth used to smooth the covariate in the nonparametric estimation of the probability of cure.
The logarithm of the bandwidth used to smooth the covariate in the nonparametric estimation of the latency.
The logarithm of the bandwidth used to smooth the time variable in the nonparametric estimation of the conditional density of susceptible individuals.
The logarithm of the bandwidth used to smooth the covariate in the nonparametric estimation of the conditional density of susceptible individuals.
The radius of the moving window used to smooth the nonparametric estimation of the probability of cure.
The number of nearest neighbors used to smooth the nonparametric estimation of the conditional density of susceptible individuals.